##  Related Information
  * [Platform Modeling Guidelines](https://help.sap.com/docs/leanix/ea/platform-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model platforms. This includes best practices and applicable use cases, and common antipatterns.")
  * [Initiative Modeling Guidelines](https://help.sap.com/docs/leanix/ea/initiative-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model initiatives. This includes best practices and applicable use cases, and common antipatterns.")
  * [Application Modeling Guidelines](https://help.sap.com/docs/leanix/ea/application-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "This page guides you on modeling applications, covering subtypes, best practices, versioning, hierarchies, and use cases. Avoid common antipatterns and gain valuable insights.")
